@@ -2,19 +2,20 @@ package Mac::FSEvents;
 
 use 5.008008;
 use strict;
-use base 'Exporter';
+use warnings;
+use Exporter 'import';
 
 use Mac::FSEvents::Event;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 our @EXPORT_OK   = qw(NONE WATCH_ROOT);
 our %EXPORT_TAGS = ( flags => \@EXPORT_OK );
 
 my @maybe_export_ok = qw(IGNORE_SELF FILE_EVENTS);
 
-require XSLoader;
-XSLoader::load('Mac::FSEvents', $VERSION);
+use XSLoader;
+XSLoader::load(__PACKAGE__, $VERSION);
 
 my %const_args;
 
@@ -249,14 +250,12 @@ Stop watching.
 
 =back
 
-=head1 SEE ALSO
-
-http://developer.apple.com/documentation/Darwin/Conceptual/FSEvents_ProgGuide
-
 =head1 AUTHOR
 
 Andy Grundman, E<lt>andy@hybridized.orgE<gt>
 
+Rob Hoelz, <rob@hoelz.ro>
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2009 by Andy Grundman
